package Task::CPANAuthors::STRO;

# $Id: STRO.pm 19 2009-12-23 17:40:47Z stro $

use strict;
use warnings;

our $VERSION = '2009.1223';

1;

=head1 NAME

Task::CPANAuthors::STRO - "Task" for installing modules maintained by STRO

=head1 SYNOPSIS

 perl -MCPAN -e 'install CPAN::Reporter'
 perl -MCPAN -e 'o conf init test_report'
 perl -MCPAN -e 'install Task::CPANAuthors::STRO'

=head1 CONTENTS

CGI-Application-Plugin-DevPopup-Params

CGI-Application-Plugin-DevPopup-Query

Data::Define

FindBin::Real

FTN::Address

FTN::Nodelist

Lingua::Cyrillic::Translit::ICAO

Lingua::Multinational::Translit::ICAO

Lingua::RU::Jcuken

Lingua::EN::Jcuken

Prompt::Timeout

Text::Compare

Win32::Uptime

WWW::DreamHost::API

=head1 DESCRIPTION

Task:: of modules I maintain.

=head1 AUTHOR

Serguei Trouchelle E<lt>F<stro@cpan.org>E<gt>

=head1 LICENSE AND COPYRIGHT

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut 
